summaryrefslogtreecommitdiffstats
path: root/kbackgammon/engines/nextgen/kbgng.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commita13e26c2f1eb3c5be81acf4f571dd4bafac10199 (patch)
tree1f1d3e407ae668b1448847970b2f1b626083faf6 /kbackgammon/engines/nextgen/kbgng.h
parent24c5cdc2737fe0044b11a12359606973eb93fc0b (diff)
downloadtdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.tar.gz
tdegames-a13e26c2f1eb3c5be81acf4f571dd4bafac10199.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdegames@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kbackgammon/engines/nextgen/kbgng.h')
-rw-r--r--kbackgammon/engines/nextgen/kbgng.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kbackgammon/engines/nextgen/kbgng.h b/kbackgammon/engines/nextgen/kbgng.h
index 12c94140..670a7849 100644
--- a/kbackgammon/engines/nextgen/kbgng.h
+++ b/kbackgammon/engines/nextgen/kbgng.h
@@ -58,7 +58,7 @@ public:
/*
* Constructor and destructor
*/
- KBgEngineNg( TQWidget *tqparent = 0, TQString *name = 0, TQPopupMenu *pmenu = 0);
+ KBgEngineNg( TQWidget *parent = 0, TQString *name = 0, TQPopupMenu *pmenu = 0);
virtual ~KBgEngineNg();
/**
@@ -245,7 +245,7 @@ private:
/**
* Create the i-th player. Legal values for i are 0 and 1. The
* name of the player is taken from @ref _name and the tqparent of
* the player is @ref _player. That means that the players are
* automatically deleted.
*/
@@ -245,7 +245,7 @@ private:
/**
* Create the i-th player. Legal values for i are 0 and 1. The
- * name of the player is taken from @ref _name and the tqparent of
+ * name of the player is taken from @ref _name and the parent of
* the player is @ref _player. That means that the players are
* automatically deleted.